#
# Copyright (c) 2008-2017 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
from persistent import Persistent

# import interfaces
from pyams_content.component.paragraph.interfaces.contact import IContactParagraph
from pyams_content.features.renderer.interfaces import IContentRenderer
from pyams_default_theme.component.paragraph.interfaces.contact import IContactParagraphDefaultRendererSettings
from pyams_skin.layer import IPyAMSLayer
from zope.annotation.interfaces import IAnnotations

# import packages
from pyams_content.features.renderer.zmi import BaseContentRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from zope.interface import implementer
from zope.location import locate, Location
from zope.schema.fieldproperty import FieldProperty

from pyams_default_theme import _


#
# Contact paragraph default renderer settings
#

CONTACT_DEFAULT_RENDERER_SETTINGS_KEY = 'pyams_content.contact.renderer:default'


@implementer(IContactParagraphDefaultRendererSettings)
class ContactParagraphDefaultRendererSettings(Persistent, Location):
    """Contact paragraph default renderer settings"""

    display_photo = FieldProperty(IContactParagraphDefaultRendererSettings['display_photo'])
    photo_position = FieldProperty(IContactParagraphDefaultRendererSettings['photo_position'])
    display_map = FieldProperty(IContactParagraphDefaultRendererSettings['display_map'])
    map_position = FieldProperty(IContactParagraphDefaultRendererSettings['map_position'])

    def can_display_photo(self):
        contact = IContactParagraph(self.__parent__)
        if not contact.photo:
            return False
        return self.display_photo

    def can_display_map(self):
        contact = IContactParagraph(self.__parent__)
        if not contact.gps_location:
            return False
        return self.display_map


@adapter_config(context=IContactParagraph, provides=IContactParagraphDefaultRendererSettings)
def ContactParagraphDefaultRendererSettingsFactory(context):
    """Contact paragraph default renderer settings factory"""
    annotations = IAnnotations(context)
    settings = annotations.get(CONTACT_DEFAULT_RENDERER_SETTINGS_KEY)
    if settings is None:
        settings = annotations[CONTACT_DEFAULT_RENDERER_SETTINGS_KEY] = ContactParagraphDefaultRendererSettings()
        locate(settings, context)
    return settings


#
# Contact paragraph default renderer
#

@adapter_config(name='default', context=(IContactParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/contact-default.pt', layer=IPyAMSLayer)
class ContactParagraphDefaultRenderer(BaseContentRenderer):
    """Context paragraph default renderer"""

    label = _("Default contact renderer")

    settings_interface = IContactParagraphDefaultRendererSettings

    context_attrs = ('name', 'photo', 'gps_location', 'address')
    i18n_context_attrs = ('title', 'charge', )
