#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.features.preview.interfaces import IPreviewTarget
from pyams_content.features.renderer.interfaces import IContentRenderer
from pyams_default_theme.layer import IPyAMSDefaultLayer
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION

# import packages
from pyams_pagelet.pagelet import pagelet_config
from pyams_template.template import layout_config, template_config


@pagelet_config(name='', layer=IPyAMSDefaultLayer)
@layout_config(template='templates/layout.pt', layer=IPyAMSDefaultLayer)
@template_config(template='templates/index.pt', layer=IPyAMSDefaultLayer)
class BaseIndexPage(object):
    """Default base index page"""


@pagelet_config(name='preview.html', context=IPreviewTarget, layer=IPyAMSDefaultLayer,
                permission=VIEW_SYSTEM_PERMISSION)
class PreviewPage(BaseIndexPage):
    """Preview page"""

    def __init__(self, context, request):
        super(PreviewPage, self).__init__(context, request)
        self.language = self.request.params.get('lang')
        self.renderers = sorted(self.request.registry.getAdapters((self.context, self.request), IContentRenderer),
                                key=lambda x: getattr(x[1], 'weight', 0))

    def update(self):
        super(PreviewPage, self).update()
        for name, renderer in self.renderers:
            renderer.language = self.language
            renderer.update()

    def render(self):
        result = ''
        for name, renderer in self.renderers:
            result += renderer.render()
        return result
